from albion_api_client import AlbionAPI
import requests
import json
import sqlite3
import pandas as pd

class CustomAlbionAPI(AlbionAPI):
    def __init__(self, path:str = ""):
        # Connect to (or create) the database
        self.conn = sqlite3.connect(path + "data/game_stats.db")
        # Create a cursor object
        self.cursor = self.conn.cursor()
        
    def _url(self, endpoint):
        URL = 'https://gameinfo-ams.albiononline.com/api/gameinfo'
        # 'https://gameinfo-ams.albiononline.com/api/gameinfo'
        return URL + endpoint
        
    def search(self, query):
        params = {}
        params['q'] = query
        response = requests.get(self._url('/search'), params=params).json()
        if 'code' in response and response['code'] != 200:
            raise Exception(f"Error: API request failed with status code {response['code']}")
        return response
    
    def get_battle(self, battleID:int ,offset:int=0, limit:int=51):
        params = {}
        params['offset'] = offset
        params['limit'] = limit
        return requests.get(self._url(f'/events/battle/{battleID}'),
                            params=params).json()
    
    def get_recent_events(self, guildID:str, limit:int=50, offset:int=0):
        params = {}
        params['limit'] = limit
        params['offset'] = offset
        params['guildId'] = guildID

        return requests.get(self._url('/events'), params=params).json()
    
    def get_battles_guild(self, guildID, offset=0, limit=51, sort='recent'):
        params = {}
        params['guildId'] = guildID
        params['offset'] = offset
        params['limit'] = limit
        if sort and sort in ['recent', 'topfame']:
            params['sort'] = sort

        return requests.get(self._url('/battles'),
                            params=params).json()
    
    def save_battles(self,df_battles):
        df_battles.to_sql("game_results", self.conn, if_exists="append", index=False)
        
    def read_battles(self):
        return pd.read_sql_query("SELECT * FROM game_results", self.conn)
    
